SystemOrganization addCategory: #ConfigurationOfSeaside31!

Object subclass: #ConfigurationOfComet31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfComet31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:31'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfComet31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:31'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfComet31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfComet31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfComet31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:31'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfComet31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:31'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfComet31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfComet31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:31'!
project

	^self new project! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfComet31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfComet31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:06'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'Javascript Core' with: [
				spec
					className: 'ConfigurationOfJavascript31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'JQueryUI Core' with: [
				spec
					className: 'ConfigurationOfJQueryUI31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Comet-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Canvas' ) ];
			package: 'Comet-Tests-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Comet-Core' ) ];
			package: 'Comet-Examples' with: [
				spec requires: #('JQuery-UI' 'Comet-Core'). ].
		spec 
			group: 'Base' with: #('Comet-Core');
			group: 'Base Tests' with: #('Comet-Tests-Core' );
			group: 'Base Examples' with: #('Comet-Examples' ) ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Comet-Core' with: [
				spec includes: #('Comet-Pharo-Core' ) ] ]
! !

!ConfigurationOfComet31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfComet31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfComet31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:31'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfComet31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfComet31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 10:15'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0'.
		spec 
			project: 'Javascript Core' with: '3.1.0'.
		spec 
			project: 'JQueryUI Core' with: '3.1.0'.
		spec 
			package: 'Comet-Core' with: 'Comet-Core-pmm.53';
			package: 'Comet-Examples' with: 'Comet-Examples-lr.25';
			package: 'Comet-Tests-Core' with: 'Comet-Tests-Core-lr.11' ].
		
	spec for: #'pharo' do: [
		spec package: 'Comet-Pharo-Core' with: 'Comet-Pharo-Core-lr.6' ]


! !

Object subclass: #ConfigurationOfJQuery31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfJQuery31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 10:24'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfJQuery31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 10:24'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfJQuery31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:24'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfJQuery31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:24'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfJQuery31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 10:24'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfJQuery31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 10:24'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfJQuery31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:24'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfJQuery31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 10:24'!
project

	^self new project! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfJQuery31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:24'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfJQuery31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 11:10'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'Javascript Core' with: [
				spec
					className: 'ConfigurationOfJavascript31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'JSON Core' with: [
				spec
					className: 'ConfigurationOfJson31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'JQuery-Core' with: [
				spec requires: #('Javascript-Core' ) ];
			package: 'JQuery-Tests-Core' with: [
				spec requires: #('JQuery-Core' 'Javascript-Tests-Core' 'Seaside-Development' 'Seaside-Tests-Functional') ];
			package: 'JQuery-JSON' with: [
				spec requires: #('JQuery-Core' 'Seaside-JSON-Core') ];
			package: 'JQuery-Tests-JSON' with: [
				spec requires: #('JQuery-JSON' 'JQuery-Tests-Core') ].
		spec 
			group: 'Base' with: #('JQuery-Core');
			group: 'Base Tests' with: #('JQuery-Tests-Core');
			group: 'JSON' with: #('JQuery-JSON');
			group: 'JSON Tests' with: #('JQuery-Tests-JSON') ]! !

!ConfigurationOfJQuery31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:24'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfJQuery31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:24'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfJQuery31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 10:24'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfJQuery31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:24'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfJQuery31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 11:12'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0';
			project: 'Javascript Core' with: '3.1.0';
			project: 'JSON Core' with: '3.1.0'.
		spec 
			package: 'JQuery-Core' with: 'JQuery-Core-pmm.125';
			package: 'JQuery-JSON' with: 'JQuery-JSON-pmm.1';
			package: 'JQuery-Tests-Core' with: 'JQuery-Tests-Core-pmm.135';
			package: 'JQuery-Tests-JSON' with: 'JQuery-Tests-JSON-pmm.1' ].


! !

Object subclass: #ConfigurationOfJQueryUI31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfJQueryUI31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:39'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfJQueryUI31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:39'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfJQueryUI31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:39'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfJQueryUI31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:39'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfJQueryUI31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:39'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfJQueryUI31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:39'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfJQueryUI31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:39'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfJQueryUI31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:39'!
project

	^self new project! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfJQueryUI31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:39'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfJQueryUI31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:09'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'JQuery Core' with: [
				spec
					className: 'ConfigurationOfJQuery31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'JQuery-UI' with: [
				spec requires: #('JQuery-Core' ) ];
			package: 'JQuery-Tests-UI' with: [
				spec requires: #('JQuery-UI' 'JQuery-Tests-Core' ) ].
		spec 
			group: 'Base' with: #('JQuery-UI');
			group: 'Base Examples' with: #('JQuery-Tests-UI' ) ].
		
	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone' ].
! !

!ConfigurationOfJQueryUI31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:39'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfJQueryUI31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:39'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfJQueryUI31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:39'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfJQueryUI31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:39'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfJQueryUI31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 13:11'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0';
			project: 'JQuery Core' with: '3.1.0'.
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI-lr.83';
			package: 'JQuery-Tests-UI' with: 'JQuery-Tests-UI-lr.83' ].
		
	spec for: #'gemstone' do: [
		spec 
			package: 'JQuery-UI' with: 'JQuery-UI.gemstone-dkh.81' ]


! !

Object subclass: #ConfigurationOfJavascript31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfJavascript31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:31'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfJavascript31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:31'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfJavascript31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfJavascript31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfJavascript31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:31'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfJavascript31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:31'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfJavascript31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:31'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfJavascript31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:31'!
project

	^self new project! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfJavascript31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:31'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfJavascript31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:06'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Javascript-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ) ];
			package: 'Javascript-Tests-Core' with: [
				spec requires: #('Javascript' 'Seaside-Tests-Core' ) ].
		spec 
			group: 'Base' with: #('Javascript-Core');
			group: 'Base Tests' with: #('Javascript-Tests-Core' ) ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Javascript-Pharo-Core' with: [
				spec requires: #('Javascript-Core' 'Seaside-Pharo-Core' ) ].
		spec 
			package: 'Javascript-Tests-Pharo-Core' with: [
				spec requires: #('Javascript-Tests-Core' 'Javascript-Pharo-Core' ) ].
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-Pharo-Core' ) ];
			package: 'Javascript-Tests-Core' with: [
				spec includes: #('Javascript-Tests-Pharo-Core' ) ] ].
		
	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			package: 'Javascript-Core' with: [
				spec includes: #('Javascript-GemStone-Core' ). ];
			package: 'Javascript-GemStone-Core' with: [
				spec requires: #('Javascript-Core' ) ] ].
! !

!ConfigurationOfJavascript31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfJavascript31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfJavascript31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:31'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfJavascript31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:31'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfJavascript31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 11:40'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0'.
		spec 
			package: 'Javascript-Core' with: 'Javascript-Core-pmm.95';
			package: 'Javascript-Tests-Core' with: 'Javascript-Tests-Core-pmm.68' ].
		
	spec for: #'pharo' do: [
		spec
			package: 'Javascript-Pharo-Core' with: 'Javascript-Pharo-Core-pmm.10';
			package: 'Javascript-Tests-Pharo-Core' with: 'Javascript-Tests-Pharo-Core-lr.1' ].

	spec for: #'gemstone' do: [
		spec 
			package: 'Javascript-GemStone-Core' with: 'Javascript-GemStone-Core-DaleHenrichs.4' ].! !

Object subclass: #ConfigurationOfJson31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfJson31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 10:18'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfJson31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 10:18'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfJson31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:18'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfJson31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:18'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfJson31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 10:18'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfJson31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 10:18'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfJson31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 10:18'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfJson31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 10:18'!
project

	^self new project! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfJson31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 10:18'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfJson31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:06'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Seaside-JSON-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ) ];
			package: 'Seaside-Tests-JSON' with: [
				spec requires: #('Seaside-JSON-Core' ) ].
		spec 
			group: 'Base' with: #('Seaside-JSON-Core');
			group: 'Base Tests' with: #('Seaside-Tests-JSON' ) ]! !

!ConfigurationOfJson31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:18'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfJson31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:18'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfJson31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 10:18'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfJson31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 10:18'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfJson31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 10:22'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0'.
		spec 
			package: 'Seaside-JSON-Core' with: 'Seaside-JSON-Core-pmm.13';
			package: 'Seaside-Tests-JSON' with: 'Seaside-Tests-JSON-pmm.6' ]


! !

Object subclass: #ConfigurationOfRss31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfRss31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:08'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfRss31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 08:08'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfRss31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:08'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRss31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:08'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfRss31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:08'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfRss31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 08:08'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfRss31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 08:08'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfRss31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:08'!
project

	^self new project! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfRss31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 08:08'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfRss31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:07'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'RSS-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' ) ];
			package: 'RSS-Tests-Core' with: [
				spec requires: #('RSS-Core' 'Seaside-Tests-Core' ) ];
			package: 'RSS-Examples' with: [
				spec requires: #('RSS-Core' 'Seaside-Tools-Core'). ].
		spec 
			group: 'Base' with: #('RSS-Core');
			group: 'Base Tests' with: #('RSS-Tests-Core' );
			group: 'Base Examples' with: #('RSS-Examples' ) ].
! !

!ConfigurationOfRss31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:08'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfRss31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:08'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfRss31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 08:09'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfRss31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:08'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfRss31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 08:25'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0'.
		spec 
			package: 'RSS-Core' with: 'RSS-Core-pmm.68';
			package: 'RSS-Examples' with: 'RSS-Examples-lr.26';
			package: 'RSS-Tests-Core' with: 'RSS-Tests-Core-lr.30' ].


! !

Object subclass: #ConfigurationOfScriptaculous31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfScriptaculous31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 11:27'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfScriptaculous31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 11:27'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfScriptaculous31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 11:27'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfScriptaculous31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 11:27'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfScriptaculous31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 11:27'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfScriptaculous31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 11:27'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfScriptaculous31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 11:27'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfScriptaculous31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 11:27'!
project

	^self new project! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfScriptaculous31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 11:27'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfScriptaculous31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 11:32'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'Javascript Core' with: [
				spec
					className: 'ConfigurationOfJavascript31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Prototype-Core' with: [
				spec requires: #('Javascript-Core' ) ];
			package: 'Prototype-Tests-Core' with: [
				spec requires: #('Prototype-Core' 'Javascript-Tests-Core' 'Seaside-Tests-Functional') ];
			package: 'Scriptaculous-Core' with: [
				spec requires: #('Prototype-Core') ];
			package: 'Scriptaculous-Tests-Core' with: [
				spec requires: #('Scriptaculous-Core' 'Prototype-Tests-Core') ];
			package: 'Scriptaculous-Components' with: [
				spec requires: #('Scriptaculous-Core' 'Seaside-Flow' 'Seaside-Widgets' 'Seaside-Component') ];
			package: 'Scriptaculous-Tests-Components' with: [
				spec requires: #('Scriptaculous-Components' 'Scriptaculous-Tests-Core') ].
		spec 
			group: 'Base' with: #('Scriptaculous-Core' 'Scriptaculous-Components');
			group: 'Base Tests' with: #('Prototype-Tests-Core' 'Scriptaculous-Tests-Core' 'Scriptaculous-Tests-Components') ]! !

!ConfigurationOfScriptaculous31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 11:27'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfScriptaculous31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 11:27'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfScriptaculous31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 11:27'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfScriptaculous31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 11:27'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfScriptaculous31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 11:35'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0';
			project: 'Javascript Core' with: '3.1.0'.
		spec 
			package: 'Prototype-Core' with: 'Prototype-Core-pmm.27';
			package: 'Prototype-Tests-Core' with: 'Prototype-Tests-Core-pmm.16';
			package: 'Scriptaculous-Core' with: 'Scriptaculous-Core-pmm.103';
			package: 'Scriptaculous-Tests-Core' with: 'Scriptaculous-Tests-Core-pmm.62';
			package: 'Scriptaculous-Components' with: 'Scriptaculous-Components-pmm.112';
			package: 'Scriptaculous-Tests-Components' with: 'Scriptaculous-Tests-Components-pmm.40' ].


! !

Object subclass: #ConfigurationOfSeaside31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfSeaside31 commentStamp: 'pmm 5/8/2012 19:22' prior: 0!
The following load expression will load the 'default' group for Seaside3.1:

   (ConfigurationOfSeaside31 project version: '3.1.0') load.

   alternatively you can also load the stable version using:
	 (ConfigurationOfSeaside31 project version: #stable) load.

By default all of the packages and projects associated with the Seaside31 
project will be loaded.

Here is the list of groups for Seaside 3.1:

   - 'Base'
   - 'Base Tests'
   - 'Development'
   - 'Development Tests'
   - 'Core'
   - 'Tests'
   - 'OneClick'

The '... Tests' group include the test packages for the named group:

   - 'Base' is the absolute minimum set of packages that should be
     loaded to get expected Seaside3.1 functionality
   - 'Development' adds in the Seaside31 development tools. It should be
     noted that it is recommended that the Seaside31 development tools
     be loaded in a production image, because the tools are considered
     essential
   - 'Core' includes "optional" packages like javascript support,
     adaptors, etc.
   - 'OneClick' is the subset of 'Core' that is shipped in the one-click
     image

It is recommended that you load the 'Core' group, if you want to exclude 
the tests and load the 'default' group (i.e., everything) if you want to 
include the tests.

Here's the list of packages in the 'Core' group:

   - 'Comet-Core' 'Seaside-Examples' 'Scriptaculous-Core'
     'Seaside-Tools-Core' 'Seaside-Tools-OmniBrowser' 'Seaside-HTML5'
     'Seaside-Environment' 'Seaside-Core' 'Seaside-Adaptors-Swazoo'
     'Seaside-Widgets' 'Seaside-Flow' 'Seaside-InternetExplorer'
     'Javascript-Core' 'JQuery-UI' 'Seaside-Adaptors-Comanche'
     'Seaside-Development' 'Seaside-Component' 'Seaside-Canvas'
     'RSS-Examples' 'RSS-Core' 'Scriptaculous-Components' 'JQuery-Core'
     'Seaside-FileSystem' 'Seaside-Session' 'Seaside-Email'
     'Seaside-Tools-Web' 'Comet-Examples' 'Seaside-RenderLoop'
     'Seaside-Welcome' 'Prototype-Core' 'Seaside-Swazoo' 'Seaside-Slime'

You must choose at least one adaptor (Seaside-Adaptors-Swazoo or Seaside-Adaptors-Comanche), so in 
theory the absolute minimum loadable unit for Seaside31 would be:

   (ConfigurationOfSeaside31 project version: '3.1.3')
     load: #('Base' 'Seaside-Adaptors-Comanche').

Note that there are no pre-defined components registered in this case, 
so even if you manually start WAKom:

   WAKom startOn: 8080

the only page you can hit is the files page:

   http://localhost:8080/files

You could load the example packages:

  (ConfigurationOfSeaside31 project version: '3.1.0')
     load: #('Seaside-Examples').

to have a few more pages to hit:

   http://localhost:8080/examples/examplebrowser

but without the familiar development tools you might not have an 
enjoyable experience. You can add in the development tools with the 
following expression:

  (ConfigurationOfSeaside31 project version: '3.1.0')
     load: #('Development').

Only then will you see the familiar Dispatcher page when you hit:

   http://localhost:8080/

At this point in time, the only things that you won't have loaded 
(because of package dependencies) are:

   - Comet
   - Swazoo
   - RSS support
   - javascript support
   - HTML5 support
   - EMail
   - Welcome page

To add the remaining pieces you'd now have to list the individual 
packages!

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'NickAger 3/23/2012 16:50'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfSeaside31 class methodsFor: 'private' stamp: 'dkh 11/05/2009 16:55'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/14/2011 11:50'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:20'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 13:20'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 2/9/2011 11:39'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 2/9/2011 11:42'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:01'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSeaside31 class methodsFor: 'private' stamp: 'DaleHenrichs 06/20/2010 16:22'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSeaside31 class methodsFor: 'metacello tool support' stamp: 'dkh 11/05/2009 16:55'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSeaside31 class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSeaside31 class methodsFor: 'loading' stamp: 'DaleHenrichs 12/19/2009 10:53'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfSeaside31 class methodsFor: 'loading' stamp: 'dkh 11/05/2009 16:55'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSeaside31 class methodsFor: 'metacello tool support' stamp: 'dkh 11/13/2009 16:33'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSeaside31 class methodsFor: 'accessing' stamp: 'dkh 11/05/2009 16:55'!
project

	^self new project! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:05'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:56'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 02/11/2011 17:42'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSeaside31 class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:57'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSeaside31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 14:04'!
baseline310: spec
	<version: '3.1.0-baseline' imports: #('3.1.0-baseline-commonBaseline' )>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec 
			package: 'Seaside-FileSystem' with: [
				spec 
					requires: #('Seaside-Core' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Seaside-Tests-FileSystem' with: [
				spec 
					requires: #('Seaside-FileSystem' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ].
		spec 
			group: 'default' with: #('Core' 'Tests');
			group: 'Core' with: #('Base' 'Development' 'Seaside-HTML5' 'Seaside-Tools-Web' 'Seaside-Swazoo' 'Seaside-Adaptors-Swazoo' 'Seaside-Tools-OmniBrowser' 'Seaside-FileSystem' );
			group: 'Examples' with: #('Seaside-Examples');
			group: 'Tests' with: #('Base Tests' 'Development Tests' 'Seaside-Tests-Functional' 'Seaside-Tests-HTML5' 'Seaside-Tests-Examples' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-UTF8' 'Seaside-Tests-FileSystem'). ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: [
				spec
					className: 'ConfigurationOfKomHttpServer';
					versionString: #'bleedingEdge';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: #'stable';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'SPort2' with: [
				spec
					className: 'ConfigurationOfSPort2';
					versionString: '2.31';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-Pharo-Core' ). ];
			package: 'Seaside-Canvas' with: [
				spec includes: #('Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-Pharo-Development' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-Pharo-Email' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-Pharo-Environment' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-Pharo-Tools-Web' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-Pharo-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-Pharo-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-Pharo-Functional' ). ];
			package: 'Seaside-Pharo-Canvas' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Pharo-Core' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Pharo-Continuation';
			package: 'Seaside-Pharo-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Pharo-Tools-Web' 'Seaside-Pharo-Flow' ). ];
			package: 'Seaside-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Core' ). ];
			package: 'Seaside-Pharo-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Pharo-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-Pharo-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Pharo-Core' 'Seaside-Pharo-Canvas' ). ];
			package: 'Seaside-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Core' 'Kom' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('SPort2' ). ];
			package: 'Seaside-Tests-Pharo-Continuation' with: [
				spec requires: #('Seaside-Pharo-Continuation' ). ];
			package: 'Seaside-Tests-Pharo-Core' with: [
				spec requires: #('Seaside-Pharo-Core' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Pharo-Development' with: [
				spec requires: #('Seaside-Tests-Development' 'Seaside-Pharo-Development' ). ];
			package: 'Seaside-Tests-Pharo-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Pharo-Email' 'Grease Core Tests'). ];
			package: 'Seaside-Tests-Pharo-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' 'Seaside-Tests-Environment' 'Seaside-Pharo-Environment' 'Seaside-Tests-Pharo-Core' ). ];
			package: 'Seaside-Tests-Adaptors-Comanche' with: [
				spec requires: #('Seaside-Adaptors-Comanche' 'Seaside-Tests-Pharo-Core' ). ].
		spec 
			group: 'Core' with: #('Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples' );
			group: 'Tests' with: #('Comet-Tests-Core' 'Seaside-Tests-Adaptors-Comanche' ). ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime' ) ];
			project: 'Grease Slime Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Slime Tests' ) ].
		spec
			package: 'Seaside-Slime' with: [
				spec requires: #('Grease Slime' ). ];
			package: 'Seaside-Tests-Slime' with: [
				spec requires: #('Seaside-Slime' 'Seaside-Tests-Component' 'Grease Slime Tests' ). ].
		spec 
			group: 'Development' with: #('Seaside-Slime' );
			group: 'Development Tests' with: #('Seaside-Tests-Slime' ). ].

	spec for: #'gemstone' do: [
		spec repository: 'http://seaside.gemstone.com/ss/Seaside30'.
		spec 
			project: 'GsCore' with: [
				spec
					className: 'ConfigurationOfGsCore';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'FastCGI' with: [
				spec
					className: 'ConfigurationOfGsFastCGI';
					versionString: #'stable';
					loads: #('FastCGI' );
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					versionString: #'stable';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ].
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-Development' with: [
				spec includes: #('Seaside-GemStone-Development' ). ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Swazoo' ). ];
			package: 'Zinc-Seaside' with: [
				spec includes: #('Seaside-GemStone-Adaptors-Zinc' ). ];
			package: 'Seaside-Email' with: [
				spec includes: #('Seaside-GemStone-Email' ). ];
			package: 'Seaside-Flow' with: [
				spec includes: #('Seaside-GemStone-Flow' ). ];
			package: 'Seaside-Environment' with: [
				spec includes: #('Seaside-GemStone-Environment' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-Session' with: [
				spec 
					includes: #('Seaside-GemStone-Session' );
					file: 'Seaside-Session.gemstone'. ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec 
					requires: #('OB' );
					includes: #('Seaside-GemStone-Tools-OmniBrowser' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec includes: #('Seaside-GemStone-Tools-Web' ). ];
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-GemStone-Welcome' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec includes: #('Seaside-Tests-GemStone-Core' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec includes: #('Seaside-Tests-GemStone-Development' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec includes: #('Seaside-Tests-GemStone-Continuation' 'Seaside-Tests-GemStone-Flow' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec includes: #('Seaside-Tests-GemStone-Functional' ). ];
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone';
			package: 'Seaside-GemStone-Basic-Development' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-GemStone-Continuation';
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-Core' 'GsCore' ). ];
			package: 'Seaside-GemStone-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-GemStone-Basic-Development' 'Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Email' with: [
				spec requires: #('Seaside-Email' ). ];
			package: 'Seaside-GemStone-Environment' with: [
				spec requires: #('Seaside-Environment' ). ];
			package: 'Seaside-GemStone-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-GemStone-ServiceTask' with: [
				spec requires: #('Seaside-GemStone-Tools-Production' ). ];
			package: 'Seaside-GemStone-Session' with: [
				spec requires: #('Seaside-Session' ). ];
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-OmniBrowser' ). ];
			package: 'Seaside-GemStone-Tools-Production' with: [
				spec requires: #('Seaside-Widgets' 'Seaside-GemStone-Basic-Development' ). ];
			package: 'Seaside-GemStone-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' ). ];
			package: 'Seaside-GemStone-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ];
			package: 'Seaside-Adaptors-FastCGI' with: [
				spec requires: #('Seaside-Core' 'FastCGI' ). ];
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Adaptors-Swazoo' ). ];
			package: 'Seaside-GemStone-Adaptors-Zinc' with: [
				spec requires: #('Zinc-Seaside' ). ];
			package: 'Seaside-FileSystem' with: [
				spec requires: #('GsCore' ). ];
			package: 'Seaside-Tests-GemStone-Core' with: [
				spec requires: #('Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-GemStone-Development' with: [
				spec requires: #('Seaside-Tests-Development' ). ];
			package: 'Seaside-Tests-GemStone-Continuation' with: [
				spec requires: #('Seaside-GemStone-Continuation' ). ];
			package: 'Seaside-Tests-GemStone-Flow' with: [
				spec requires: #('Seaside-Tests-Flow' ). ];
			package: 'Seaside-Tests-GemStone-Functional' with: [
				spec requires: #('Seaside-Tests-Functional' ). ].
		spec 
			group: 'Base' with: #('Seaside-GemStone-Basic-Development' );
			group: 'Core' with: #('Seaside-Adaptors-FastCGI' ). ].

	spec for: #'gs2.4.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone240-Core' ). ];
			package: 'Seaside-GemStone240-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone240-Core' ). ]. ].

	spec for: #'gs3.x' do: [
		spec 
			package: 'Seaside-Core' with: [
				spec includes: #('Seaside-GemStone300-Core' ). ];
			package: 'Seaside-GemStone300-Core' with: [
				spec 
					requires: #('Seaside-Core' );
					includes: #('Seaside-GemStone-Core' ). ];
			package: 'Seaside-GemStone-Core' with: [
				spec requires: #('Seaside-GemStone300-Core' ). ]. ].
! !

!ConfigurationOfSeaside31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 14:04'!
baseline310commonBaseline: spec
	<version: '3.1.0-baseline-commonBaseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Grease Core' with: [
				spec
					className: 'ConfigurationOfGrease';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Grease Core Tests' copyFrom: 'Grease Core' with: [
				spec loads: #('Core Tests' ) ];
			project: 'Swazoo2' with: [
				spec
					className: 'ConfigurationOfSwazoo2';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Zinc' with: [
				spec
					className: 'ConfigurationOfZincHTTPComponents';
					versionString: #'stable';
					loads: #('Zinc-HTTP');
					repository: 'http://www.squeaksource.com/ZincHTTPComponents' ].
		spec
			package: 'Seaside-Canvas' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Component' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Core' with: [
				spec 
					postLoadDoIt: #seaside304DoIts;
					requires: #('Grease Core' ). ];
			package: 'Seaside-Development' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Flow' 'Seaside-Environment' ). ];
			package: 'Seaside-Email' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Environment' with: [
				spec requires: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Examples' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-Flow' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' ). ];
			package: 'Seaside-HTML5' with: [
				spec requires: #('Seaside-Canvas' ). ];
			package: 'Seaside-InternetExplorer' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-RenderLoop' with: [
				spec requires: #('Seaside-Component' 'Seaside-Session' ). ];
			package: 'Seaside-Session' with: [
				spec requires: #('Seaside-Core' ). ];
			package: 'Seaside-Tools-Core' with: [
				spec requires: #('Seaside-Core' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Session' ). ];
			package: 'Seaside-Tools-OmniBrowser' with: [
				spec requires: #('Seaside-Tools-Core' ). ];
			package: 'Seaside-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Core' 'Seaside-RenderLoop' 'Seaside-Widgets' ). ];
			package: 'Seaside-Widgets' with: [
				spec requires: #('Seaside-Component' 'Seaside-Canvas' ). ];
			package: 'Seaside-Swazoo' with: [
				spec 
					requires: #('Grease Core' 'Swazoo2' );
					repository: 'http://www.squeaksource.com/Seaside30LGPL'. ];
			package: 'Zinc-Seaside' with: [
				spec 
					requires: #('Seaside-Core' 'Zinc' );
					repository: 'http://www.squeaksource.com/ZincHTTPComponents'. ];
			package: 'Seaside-Adaptors-Swazoo' with: [
				spec requires: #('Seaside-Core' 'Seaside-Swazoo' ). ];
			package: 'Seaside-Tests-Canvas' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Canvas' ). ];
			package: 'Seaside-Tests-Component' with: [
				spec requires: #('Seaside-Component' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Core' with: [
				spec requires: #('Seaside-Core' 'Grease Core Tests' ). ];
			package: 'Seaside-Tests-Development' with: [
				spec requires: #('Seaside-Development' 'Seaside-Tests-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Email' with: [
				spec requires: #('Seaside-Email' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-Environment' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Session' 'Seaside-Tests-Canvas' ). ];
			package: 'Seaside-Tests-Examples' with: [
				spec requires: #('Seaside-Examples' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-Flow' with: [
				spec requires: #('Seaside-Flow' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-Functional' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tests-Core' 'Seaside-Widgets' ). ];
			package: 'Seaside-Tests-HTML5' with: [
				spec requires: #('Seaside-HTML5' 'Seaside-Tests-Functional' ). ];
			package: 'Seaside-Tests-InternetExplorer' with: [
				spec requires: #('Seaside-InternetExplorer' 'Seaside-Tests-Core' ). ];
			package: 'Seaside-Tests-RenderLoop' with: [
				spec requires: #('Seaside-RenderLoop' 'Seaside-Tests-Session' ). ];
			package: 'Seaside-Tests-Session' with: [
				spec requires: #('Seaside-Tests-Core' 'Seaside-Session' ). ];
			package: 'Seaside-Tests-Tools-Web' with: [
				spec requires: #('Seaside-Tools-Web' 'Seaside-Tests-Environment' ). ];
			package: 'Seaside-Tests-UTF8' with: [
				spec requires: #('Seaside-Tests-Core' ). ].
		spec 
			group: 'Base' with: #('Seaside-Core' 'Seaside-Canvas' 'Seaside-Session' 'Seaside-Component' 'Seaside-RenderLoop' 'Seaside-Tools-Core' 'Seaside-Flow' 'Seaside-Environment' 'Seaside-Widgets' );
			group: 'Base Tests' with: #('Base' 'Seaside-Tests-Core' 'Seaside-Tests-Canvas' 'Seaside-Tests-Session' 'Seaside-Tests-Component' 'Seaside-Tests-RenderLoop' 'Seaside-Tests-Environment' 'Seaside-Tests-Flow' );
			group: 'Development' with: #('Base' 'Seaside-Development' );
			group: 'Development Tests' with: #('Development' 'Base Tests' 'Seaside-Tests-Development' ). ].
! !

!ConfigurationOfSeaside31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:07'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfSeaside31 methodsFor: 'symbolic versions' stamp: 'NickAger 4/2/2012 06:33'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfSeaside31 methodsFor: 'accessing' stamp: 'dkh 1/11/2010 14:57'!
project

	^ project ifNil: [ | projectAttributes |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		projectAttributes := projectAttributes, ((Smalltalk at: #OBNode ifAbsent: []) == nil
			ifTrue: [ #( #'OBNotPresent' ) ]
			ifFalse: [ #( #'OBPresent' ) ]).
		projectAttributes := projectAttributes, ((Smalltalk at: #ParseTreeEnvironment ifAbsent: []) == nil
			ifTrue: [ #( #'RBNotPresent' ) ]
			ifFalse: [ #( #'RBPresent' ) ]).
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear ]! !

!ConfigurationOfSeaside31 methodsFor: 'doits' stamp: 'DaleHenrichs 02/16/2011 10:27'!
seaside304DoIts
	"see Issue 643: http://code.google.com/p/seaside/issues/detail?id=643"
	
	true ifTrue: [ ^self ].
	"When issue 643 is resolved we'll see what is really needed"
	(Smalltalk at: #WASystemConfiguration) allSubclasses do: [ :each | 
		each instance perform: #clearSearchContexts.
		each instance perform: #clearDescription ].
	"Needed for GemStone ... not clear why yet...."
	(Smalltalk at: #WAFileHandler) default: nil.
	(Smalltalk at: #WASharedConfiguration) initialize.
! !

!ConfigurationOfSeaside31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 08:07'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfSeaside31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 13:11'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Grease Core' with: '1.1.0';
			project: 'Grease Core Tests' with: '1.1.0';
			project: 'Swazoo2' with: '2.3.0.0';
			project: 'Zinc' with: #'stable'.
		spec
			package: 'Seaside-Canvas' with: 'Seaside-Canvas-pmm.122';
			package: 'Seaside-Component' with: ' Seaside-Component-pmm.94';
			package: 'Seaside-Core' with: 'Seaside-Core-pmm.773';
			package: 'Seaside-Development' with: 'Seaside-Development-pmm.161';
			package: 'Seaside-Email' with: 'Seaside-Email-pmm.22';
			package: 'Seaside-Environment' with: 'Seaside-Environment-pmm.79';
			package: 'Seaside-Examples' with: 'Seaside-Examples-lr.23';
			package: 'Seaside-FileSystem' with: 'Seaside-FileSystem-pmm.26';
			package: 'Seaside-Flow' with: 'Seaside-Flow-pmm.24';
			package: 'Seaside-HTML5' with: 'Seaside-HTML5-pmm.31';
			package: 'Seaside-InternetExplorer' with: 'Seaside-InternetExplorer-pmm.7';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop-jf.83';
			package: 'Seaside-Session' with: 'Seaside-Session-pmm.165';
			package: 'Seaside-Tools-Core' with: 'Seaside-Tools-Core-jf.22';
			package: 'Seaside-Widgets' with: 'Seaside-Widgets-pmm.29';
			package: 'Seaside-Tools-OmniBrowser' with: 'Seaside-Tools-OmniBrowser-pmm.27';
			package: 'Seaside-Tools-Web' with: 'Seaside-Tools-Web-pmm.114';
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.41';
			package: 'Seaside-Swazoo' with: 'Seaside-Swazoo-pmm.20';
			package: 'Seaside-Adaptors-Swazoo' with: 'Seaside-Adaptors-Swazoo-pmm.43';
			package: 'Zinc-Seaside' with: 'Zinc-Seaside-SvenVanCaekenberghe.22';
			package: 'Seaside-Tests-Canvas' with: 'Seaside-Tests-Canvas-dkh.58';
			package: 'Seaside-Tests-Component' with: 'Seaside-Tests-Component-jok.33';
			package: 'Seaside-Tests-Core' with: 'Seaside-Tests-Core-pmm.258';
			package: 'Seaside-Tests-Development' with: 'Seaside-Tests-Development-pmm.44';
			package: 'Seaside-Tests-Email' with: 'Seaside-Tests-Email-lr.14';
			package: 'Seaside-Tests-Environment' with: 'Seaside-Tests-Environment-pmm.28';
			package: 'Seaside-Tests-Examples' with: 'Seaside-Tests-Examples-pmm.10';
			package: 'Seaside-Tests-FileSystem' with: 'Seaside-Tests-FileSystem-lr.13';
			package: 'Seaside-Tests-Flow' with: 'Seaside-Tests-Flow-pmm.35';
			package: 'Seaside-Tests-Functional' with: 'Seaside-Tests-Functional-pmm.149';
			package: 'Seaside-Tests-HTML5' with: 'Seaside-Tests-HTML5-pmm.33';
			package: 'Seaside-Tests-InternetExplorer' with: 'Seaside-Tests-InternetExplorer-lr.9';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop-lr.13';
			package: 'Seaside-Tests-Session' with: 'Seaside-Tests-Session-jf.69';
			package: 'Seaside-Tests-Tools-Web' with: 'Seaside-Tests-Tools-Web-jf.21';
			package: 'Seaside-Tests-UTF8' with: 'Seaside-Tests-UTF8-pmm.12';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6'. ].

	spec for: #'squeakCommon' do: [
		spec 
			project: 'Kom' with: '1.0.9';
			project: 'OB' with: #'stable';
			project: 'SPort2' with: '2.31'.
		spec
			package: 'Seaside-Adaptors-Comanche' with: 'Seaside-Adaptors-Comanche-pmm.73';
			package: 'Seaside-Pharo-Canvas' with: 'Seaside-Pharo-Canvas-pmm.4';
			package: 'Seaside-Pharo-Continuation' with: 'Seaside-Pharo-Continuation-lr.5';
			package: 'Seaside-Pharo-Core' with: 'Seaside-Pharo-Core-pmm.21';
			package: 'Seaside-Pharo-Development' with: 'Seaside-Pharo-Development-pmm.60';
			package: 'Seaside-Pharo-Email' with: 'Seaside-Pharo-Email-pmm.14';
			package: 'Seaside-Pharo-Environment' with: 'Seaside-Pharo-Environment-lr.6';
			package: 'Seaside-Pharo-Flow' with: 'Seaside-Pharo-Flow-lr.5';
			package: 'Seaside-Pharo-Tools-OmniBrowser' with: 'Seaside-Pharo-Tools-OmniBrowser.pharoOB-NickAger.7';
			package: 'Seaside-Pharo-Tools-Web' with: 'Seaside-Pharo-Tools-Web-pmm.44';
			package: 'Seaside-Tests-Adaptors-Comanche' with: 'Seaside-Tests-Adaptors-Comanche-pmm.14';
			package: 'Seaside-Tests-Pharo-Continuation' with: 'Seaside-Tests-Pharo-Continuation-lr.8';
			package: 'Seaside-Tests-Pharo-Core' with: 'Seaside-Tests-Pharo-Core-pmm.28';
			package: 'Seaside-Tests-Pharo-Development' with: 'Seaside-Tests-Pharo-Development-pmm.23';
			package: 'Seaside-Tests-Pharo-Email' with: 'Seaside-Tests-Pharo-Email-pmm.1';
			package: 'Seaside-Tests-Pharo-Functional' with: 'Seaside-Tests-Pharo-Functional-pmm.14'. ].

	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1'. ].

	spec for: #'pharo' do: [
		spec 
			project: 'Grease Slime' with: '1.1.0';
			project: 'Grease Slime Tests' with: '1.1.0'.
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-lr.82';
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2';
			package: 'Seaside-Tests-Slime' with: 'Seaside-Tests-Slime-lr.42'. ].

	spec for: #'pharo1.4.x' do: [
		spec project: 'Kom' with: '1.1.0'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Seaside-Slime' with: 'Seaside-Slime-jok.80'. ].

	spec for: #'gemstone' do: [
		spec 
			project: 'GsCore' with: '0.245';
			project: 'FastCGI' with: '0.235';
			project: 'OB' with: #'stable';
			project: 'Swazoo2' with: '2.2.0.4';
			project: 'Zinc' with: '1.1'.
		spec
			package: 'Seaside-Adaptors-FastCGI' with: 'Seaside-Adaptors-FastCGI-DaleHenrichs.25';
			package: 'Seaside-Core' with: 'Seaside-Core.gemstone-dkh.769';
			package: 'Seaside-GemStone-Adaptors-Swazoo' with: 'Seaside-GemStone-Adaptors-Swazoo-dkh.5';
			package: 'Seaside-GemStone-Adaptors-Zinc' with: 'Seaside-GemStone-Adaptors-Zinc-PaulDeBruicker.4';
			package: 'Seaside-Canvas' with: 'Seaside-Canvas.gemstone-dkh.119';
			package: 'Seaside-GemStone-Basic-Development' with: 'Seaside-GemStone-Basic-Development-NickAger.25';
			package: 'Seaside-GemStone-Continuation' with: 'Seaside-GemStone-Continuation-DaleHenrichs.20';
			package: 'Seaside-GemStone-Core' with: 'Seaside-GemStone-Core-dkh.63';
			package: 'Seaside-GemStone-Development' with: 'Seaside-GemStone-Development-dkh.27';
			package: 'Seaside-GemStone-Environment' with: 'Seaside-GemStone-Environment-dkh.12';
			package: 'Seaside-GemStone-Email' with: 'Seaside-GemStone-Email-topa.13';
			package: 'Seaside-GemStone-Flow' with: 'Seaside-GemStone-Flow-DaleHenrichs.11';
			package: 'Seaside-GemStone-Session' with: 'Seaside-GemStone-Session-DaleHenrichs.3';
			package: 'Seaside-GemStone-ServiceTask' with: 'Seaside-GemStone-ServiceTask-NickAger.20';
			package: 'Seaside-GemStone-Tools-Production' with: 'Seaside-GemStone-Tools-Production-dkh.13';
			package: 'Seaside-GemStone-Tools-Web' with: 'Seaside-GemStone-Tools-Web-DaleHenrichs.4';
			package: 'Seaside-GemStone-Tools-OmniBrowser' with: 'Seaside-GemStone-Tools-OmniBrowser-DaleHenrichs.4';
			package: 'Seaside-GemStone-Welcome' with: 'Seaside-GemStone-Welcome-DaleHenrichs.1';
			package: 'Seaside-RenderLoop' with: 'Seaside-RenderLoop.gemstone-dkh.74';
			package: 'Seaside-Session' with: 'Seaside-Session.gemstone-dkh.158';
			package: 'Seaside-Tests-GemStone-Continuation' with: 'Seaside-Tests-GemStone-Continuation-DaleHenrichs.12';
			package: 'Seaside-Tests-GemStone-Core' with: 'Seaside-Tests-GemStone-Core-dkh.15';
			package: 'Seaside-Tests-GemStone-Development' with: 'Seaside-Tests-GemStone-Development-DaleHenrichs.4';
			package: 'Seaside-Tests-GemStone-Flow' with: 'Seaside-Tests-GemStone-Flow-dkh.4';
			package: 'Seaside-Tests-GemStone-Functional' with: 'Seaside-Tests-GemStone-Functional-dkh.12';
			package: 'Seaside-Tests-RenderLoop' with: 'Seaside-Tests-RenderLoop.gemstone-dkh.13'. ].

	spec for: #'gs2.4.x' do: [
		spec package: 'Seaside-GemStone240-Core' with: 'Seaside-GemStone240-Core-DaleHenrichs.3'. ].

	spec for: #'gs3.x' do: [
		spec package: 'Seaside-GemStone300-Core' with: 'Seaside-GemStone300-Core-DaleHenrichs.4'. ].
! !

Object subclass: #ConfigurationOfSeasideRest31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfSeasideRest31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 13:15'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSeasideRest31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 13:15'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSeasideRest31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:15'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSeasideRest31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:15'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSeasideRest31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 13:15'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfSeasideRest31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 13:15'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSeasideRest31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:15'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSeasideRest31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 13:15'!
project

	^self new project! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSeasideRest31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:15'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSeasideRest31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:22'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Seaside-REST-Core' with: [
				spec requires: #('Seaside-Core' ) ];
			package: 'Seaside-Tests-REST-Core' with: [
				spec requires: #('Seaside-REST-Core' ) ].
		spec 
			group: 'Base' with: #('Seaside-REST-Core');
			group: 'Base Tests' with: #('Seaside-Tests-REST-Core' ) ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Seaside-REST-Core' with: [
				spec includes: #('Seaside-Pharo-REST-Core' ) ] ].
		
	spec for: #'gemstone' do: [
		self flag: #todo ]
! !

!ConfigurationOfSeasideRest31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:15'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfSeasideRest31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:15'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfSeasideRest31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 13:15'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSeasideRest31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:15'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfSeasideRest31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 13:25'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0'.
		spec 
			package: 'Seaside-REST-Core' with: 'Seaside-REST-Core-pmm.45';
			package: 'Seaside-Tests-REST-Core' with: 'Seaside-Tests-REST-Core-pmm.27' ].
		
	spec for: #'pharo' do: [
		spec package: 'Seaside-Pharo-REST-Core' with: 'Seaside-Pharo-REST-Core-pmm.45' ].
		
	spec for: #'gemstone' do: [
		self flag: #todo ]


! !

Object subclass: #ConfigurationOfSeasideWelcome31
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSeaside31'!

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
DevelopmentProcess

"DEVELOPMENT Process
	- load current version:
	  	(self project version: #stable) load: 'ALL'.
	- open new version for development:
		self createNewDevelopmentVersion
	- update the the development version to match mcz file versions
		self updateToLatestPackageVersions: '3.0.7 release see http://code.google.com/p/seaside/wiki/Seaside307Changelog'
	- do development and periodically save mcz files and update configuration
		self saveModifiedPackages: '- fixed bug xyz'
	- do development and periodically save mcz files and configuration until ready for release
		self saveModifiedPackagesAndConfiguration: '- fixed bug xyz'
	- save configuration
		self saveConfiguration: commitMessage '- checkpoint configuration'
RELEASE Process
	- mark development version as release:
		self releaseDevelopmentVersion: 'commit comment'
	- copy configuration for general access for Squeak and Pharo:
		self copyToSqueakSource.
	- copy configuration for general access for GLASS (Dale is willing to test and release for GLASS):
		self copyToGemSource.
"! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 13:36'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
compareVersions
	"Compare the current #stable version to current #development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
copyToGemSource
	"Copy the current configuration mcz file to http://seaside.gemstone.com/ss/MetacelloRepository"

	"Note you before copying config to GemSource, you should have tested the release in GLASS.
	 You also need to have commit rights to the GemSource repository."

	"self copyToGemSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://seaside.gemstone.com/ss/MetacelloRepository'! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
copyToSqueakSource
	"Copy the current configuration mcz file to http://www.squeaksource.com/MetacelloRepository"

	"self copyToSqueakSource"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) copyConfiguration: self to: 'http://www.squeaksource.com/MetacelloRepository'! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
createNewBaselineVersion
	"Create a new baseline version based upon current version's baseline.
	 You should create a new baseline if new packages have been added or dependencies have changed."
	
	"self createNewBaselineVersion"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| currentVersion existingBaselineVersionString baselineVersionNumber |
	self ensureMetacello.
	currentVersion := self project currentVersion.
	existingBaselineVersionString := currentVersion importedVersions first.
	baselineVersionNumber := existingBaselineVersionString asMetacelloVersionNumber incrementMinorVersionNumber.
	self createNewBaselineVersion: baselineVersionNumber versionString from: existingBaselineVersionString! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
createNewBaselineVersion: baselineVersionString from: oldBaselineVersionString
	"Seaside30 baseline is made up from two baseline methods, a commonBaseline and the baseline.
	 This method creates new baseline methods"

	"self createNewBaselineVersion: '3.0.4-baseline' from: '3.0.3-baseline'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	| oldBaselineVersion oldCommonBaselineVersion commonBaselineVersionString |
	self ensureMetacello.
	oldBaselineVersion := self project version: oldBaselineVersionString.
	oldCommonBaselineVersion := self project version: oldBaselineVersion importedVersions first.
	commonBaselineVersionString := baselineVersionString , '-commonBaseline'.
	(Smalltalk at: #MetacelloToolBox)
		halt createBaseline: commonBaselineVersionString
		for: self name asString
		from: oldCommonBaselineVersion versionString
		description: ''.
	(Smalltalk at: #MetacelloToolBox)
		createBaseline: baselineVersionString
		for: self name asString
		from: oldBaselineVersionString
		description: ''.
	((Smalltalk at: #MetacelloToolBox) configurationNamed: self name asString)
		modifyVersionMethodForVersion: baselineVersionString;
		imports: {commonBaselineVersionString};
		commitMethod! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
createNewDevelopmentVersion
	"self createNewDevelopmentVersion"

	"Create a new development version using the #stable version as a model"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'private' stamp: 'pmm 5/13/2012 13:36'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
						"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:36'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:36'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 13:36'!
load
	"self load"
	
	self project latestVersion load! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'loading' stamp: 'pmm 5/13/2012 13:36'!
loadLatestVersion
	"self loadLatestVersion"
	
	^self project latestVersion load! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'metacello tool support' stamp: 'pmm 5/13/2012 13:36'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'accessing' stamp: 'pmm 5/13/2012 13:36'!
project

	^self new project! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
releaseDevelopmentVersion: commitMessage
	"Release #development version (set version blessing to #release), update the #development and #stable symbolic versions and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0.2'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
saveConfiguration: commitMessage
	"Save the configuration."

	"self saveConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveConfigurationPackageFor: self name asString description: commitMessage! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
saveModifiedPackages: commitMessage
	"Save modified mcz files and update the configuration."

	"self saveModifiedPackages: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesIn: self description:  commitMessage! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: ''"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfSeasideWelcome31 class methodsFor: 'development support' stamp: 'pmm 5/13/2012 13:36'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."
	
	"self validate"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'baselines' stamp: 'pmm 5/13/2012 13:53'!
baseline310: spec
	<version: '3.1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec repository: 'http://www.squeaksource.com/Seaside31'.
		spec 
			project: 'Seaside Core' with: [
				spec
					className: 'ConfigurationOfSeaside31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'JQuery Core' with: [
				spec
					className: 'ConfigurationOfJQuery31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'JQueryUI Core' with: [
				spec
					className: 'ConfigurationOfJQueryUI31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'RSS Core' with: [
				spec
					className: 'ConfigurationOfRss31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			project: 'Comet Core' with: [
				spec
					className: 'ConfigurationOfComet31';
					versionString: #'bleedingEdge';
					loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Seaside-Welcome' with: [
				spec requires: #('Seaside-Environment' 'Seaside-Tools-Web' 'Seaside-Widgets' 'Seaside-Examples' 'Seaside-Development' 'JQuery-Core' 'JQuery-UI' 'Seaside-Flow' 'Seaside-Tests-Flow') ];
			package: 'Seaside-Tests-Welcome' with: [
				spec requires: #('Seaside-Welcome' ) ].
		spec 
			group: 'Base' with: #('Seaside-Welcome');
			group: 'Base Tests' with: #('Seaside-Tests-Welcome' );
			group: 'OneClick' with: #('Base' 'Development' 'RSS-Core' 'Javascript-Core' 'JQuery-Core' 'JQuery-UI' 'Seaside-Email' 'Seaside-HTML5' 'Seaside-Examples' 'RSS-Examples' 'Seaside-Tools-Web' 'Seaside-Welcome' 'Seaside-Tools-OmniBrowser' 'Seaside-Adaptors-Comanche' 'Comet-Core' 'Comet-Examples') ].
		
	
	spec for: #'squeak' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Squeak-Welcome' ). ];
			package: 'Seaside-Squeak-Welcome' with: [
				spec requires: #('Seaside-Welcome' ). ]. ].
		
	spec for: #'pharo' do: [
		spec 
			package: 'Seaside-Welcome' with: [
				spec includes: #('Seaside-Pharo-Welcome' ). ];
			package: 'Seaside-Pharo-Welcome' with: [
				spec requires: #('Seaside-Welcome' ) ] ].
! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:36'!
bleedingEdge: spec
	<symbolicVersion: #'bleedingEdge'>

	spec for: #'common' version: '3.1.0-baseline'.
! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:36'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'accessing' stamp: 'pmm 5/13/2012 13:36'!
project

	^ project ifNil: [
		| constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk globals at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'symbolic versions' stamp: 'pmm 5/13/2012 13:36'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '3.1.0'.
! !

!ConfigurationOfSeasideWelcome31 methodsFor: 'versions' stamp: 'pmm 5/13/2012 14:01'!
version310: spec
	<version: '3.1.0' imports: #('3.1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'release 3.1.0 see http://code.google.com/p/seaside/wiki/Seaside310Changelog'.
		spec 
			project: 'Seaside Core' with: '3.1.0';
			project: 'JQuery Core' with: '3.1.0';
			project: 'JQueryUI' with: '3.1.0';
			project: 'RSS Core' with: '3.1.0';
			project: 'Comet Core' with: '3.1.0'.
		spec 
			package: 'Seaside-Welcome' with: 'Seaside-Welcome-pmm.41';
			package: 'Seaside-Tests-Welcome' with: 'Seaside-Tests-Welcome-lr.6' ].
		
	spec for: #'squeak' do: [
		spec package: 'Seaside-Squeak-Welcome' with: 'Seaside-Squeak-Welcome-NickAger.1' ].


	spec for: #'pharo' do: [
		spec 
			package: 'Seaside-Pharo-Welcome' with: 'Seaside-Pharo-Welcome-NickAger.2' ].! !
